======================
Slicer Package Manager
======================

|CircleCI| |Documentation|

.. |CircleCI| image:: https://circleci.com/gh/girder/slicer_package_manager.svg?style=svg
    :target: https://circleci.com/gh/girder/slicer_package_manager
    :alt: Build Status

.. |Documentation| image:: https://readthedocs.org/projects/slicer-package-manager/badge/?version=latest
    :target: https://slicer-package-manager.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

The ``Slicer Package Manager`` includes a REST API service and CLI built on `Girder`_ for downloading, uploading
and organizing application and extension packages for both `3D Slicer`_ and `3D Slicer-based`_ applications.

.. _Girder: https://github.com/girder/girder
.. _3D Slicer: https://slicer.org
.. _3D Slicer-based: https://github.com/KitwareMedical/SlicerCustomAppTemplate


Documentation is available at https://slicer-package-manager.readthedocs.io

This software is licensed under the terms of the `Apache Licence Version 2.0 <https://github.com/girder/slicer_package_manager/blob/main/LICENSE>`_.

